@@ -11,6 +11,7 @@ import (
 	"context"
 	"crypto/tls"
 	"encoding/json"
+	"log/slog"
 	"math/rand"
 	"net"
 	"net/http"
@@ -22,10 +23,11 @@ import (
 	"time"
 
 	"github.com/shirou/gopsutil/v4/process"
+	"github.com/syncthing/syncthing/internal/db"
+	"github.com/syncthing/syncthing/internal/slogutil"
 	"github.com/syncthing/syncthing/lib/build"
 	"github.com/syncthing/syncthing/lib/config"
 	"github.com/syncthing/syncthing/lib/connections"
-	"github.com/syncthing/syncthing/lib/db"
 	"github.com/syncthing/syncthing/lib/dialer"
 	"github.com/syncthing/syncthing/lib/protocol"
 	"github.com/syncthing/syncthing/lib/scanner"
@@ -41,7 +43,7 @@ const Version = 3
 var StartTime = time.Now().Truncate(time.Second)
 
 type Model interface {
-	DBSnapshot(folder string) (*db.Snapshot, error)
+	GlobalSize(folder string) (db.Counts, error)
 	UsageReportingStats(report *contract.Report, version int, preview bool)
 }
 
@@ -83,12 +85,10 @@ func (s *Service) reportData(ctx context.Context, urVersion int, preview bool) (
 	var totFiles, maxFiles int
 	var totBytes, maxBytes int64
 	for folderID := range s.cfg.Folders() {
-		snap, err := s.model.DBSnapshot(folderID)
+		global, err := s.model.GlobalSize(folderID)
 		if err != nil {
-			continue
+			return nil, err
 		}
-		global := snap.GlobalSize()
-		snap.Release()
 		totFiles += int(global.Files)
 		totBytes += global.Bytes
 		if int(global.Files) > maxFiles {
@@ -116,8 +116,8 @@ func (s *Service) reportData(ctx context.Context, urVersion int, preview bool) (
 	report.TotMiB = int(totBytes / 1024 / 1024)
 	report.FolderMaxMiB = int(maxBytes / 1024 / 1024)
 	report.MemoryUsageMiB = int((mem.Sys - mem.HeapReleased) / 1024 / 1024)
-	report.SHA256Perf = CpuBench(ctx, 5, 125*time.Millisecond, false)
-	report.HashPerf = CpuBench(ctx, 5, 125*time.Millisecond, true)
+	report.SHA256Perf = CpuBench(ctx, 5, 125*time.Millisecond)
+	report.HashPerf = report.SHA256Perf
 	report.MemorySize = int(memorySize() / 1024 / 1024)
 	report.NumCPU = runtime.NumCPU()
 
@@ -148,8 +148,6 @@ func (s *Service) reportData(ctx context.Context, urVersion int, preview bool) (
 			report.FolderUses.AutoNormalize++
 		}
 		switch cfg.Versioning.Type {
-		case "":
-			// None
 		case "simple":
 			report.FolderUses.SimpleVersioning++
 		case "staggered":
@@ -158,8 +156,6 @@ func (s *Service) reportData(ctx context.Context, urVersion int, preview bool) (
 			report.FolderUses.ExternalVersioning++
 		case "trashcan":
 			report.FolderUses.TrashcanVersioning++
-		default:
-			l.Warnf("Unhandled versioning type for usage reports: %s", cfg.Versioning.Type)
 		}
 	}
 	slices.Sort(report.RescanIntvs)
@@ -178,8 +174,6 @@ func (s *Service) reportData(ctx context.Context, urVersion int, preview bool) (
 			report.DeviceUses.CompressMetadata++
 		case config.CompressionNever:
 			report.DeviceUses.CompressNever++
-		default:
-			l.Warnf("Unhandled versioning type for usage reports: %s", cfg.Compression)
 		}
 
 		for _, addr := range cfg.Addresses {
@@ -249,14 +243,6 @@ func (s *Service) reportData(ctx context.Context, urVersion int, preview bool) (
 			if cfg.DisableSparseFiles {
 				report.FolderUsesV3.DisableSparseFiles++
 			}
-			if cfg.DisableTempIndexes {
-				report.FolderUsesV3.DisableTempIndexes++
-			}
-			if cfg.WeakHashThresholdPct < 0 {
-				report.FolderUsesV3.AlwaysWeakHash++
-			} else if cfg.WeakHashThresholdPct != 25 {
-				report.FolderUsesV3.CustomWeakHashThreshold++
-			}
 			if cfg.FSWatcherEnabled {
 				report.FolderUsesV3.FsWatcherEnabled++
 			}
@@ -322,9 +308,6 @@ func (s *Service) reportData(ctx context.Context, urVersion int, preview bool) (
 			if guiCfg.InsecureAdminAccess {
 				report.GUIStats.InsecureAdminAccess++
 			}
-			if guiCfg.Debugging {
-				report.GUIStats.Debugging++
-			}
 			if guiCfg.InsecureSkipHostCheck {
 				report.GUIStats.InsecureSkipHostCheck++
 			}
@@ -411,9 +394,9 @@ func (s *Service) Serve(ctx context.Context) error {
 			if s.cfg.Options().URAccepted >= 2 {
 				err := s.sendUsageReport(ctx)
 				if err != nil {
-					l.Infoln("Usage report:", err)
+					slog.WarnContext(ctx, "Failed to send usage report", slogutil.Error(err))
 				} else {
-					l.Infof("Sent usage report (version %d)", s.cfg.Options().URAccepted)
+					slog.InfoContext(ctx, "Sent usage report", "version", s.cfg.Options().URAccepted)
 				}
 			}
 			t.Reset(24 * time.Hour) // next report tomorrow
@@ -443,7 +426,7 @@ var (
 )
 
 // CpuBench returns CPU performance as a measure of single threaded SHA-256 MiB/s
-func CpuBench(ctx context.Context, iterations int, duration time.Duration, useWeakHash bool) float64 {
+func CpuBench(ctx context.Context, iterations int, duration time.Duration) float64 {
 	blocksResultMut.Lock()
 	defer blocksResultMut.Unlock()
 
@@ -454,7 +437,7 @@ func CpuBench(ctx context.Context, iterations int, duration time.Duration, useWe
 
 	var perf float64
 	for i := 0; i < iterations; i++ {
-		if v := cpuBenchOnce(ctx, duration, useWeakHash, bs); v > perf {
+		if v := cpuBenchOnce(ctx, duration, bs); v > perf {
 			perf = v
 		}
 	}
@@ -467,13 +450,13 @@ func CpuBench(ctx context.Context, iterations int, duration time.Duration, useWe
 	return perf
 }
 
-func cpuBenchOnce(ctx context.Context, duration time.Duration, useWeakHash bool, bs []byte) float64 {
+func cpuBenchOnce(ctx context.Context, duration time.Duration, bs []byte) float64 {
 	t0 := time.Now()
 	b := 0
 	var err error
 	for time.Since(t0) < duration {
 		r := bytes.NewReader(bs)
-		blocksResult, err = scanner.Blocks(ctx, r, protocol.MinBlockSize, int64(len(bs)), nil, useWeakHash)
+		blocksResult, err = scanner.Blocks(ctx, r, protocol.MinBlockSize, int64(len(bs)), nil)
 		if err != nil {
 			return 0 // Context done
 		}
